gm_last_response: Response from the last query

View source: R/gmailr.R

gm_last_responseR Documentation

Response from the last query

Description

gmailr now uses gargle::response_process() to process responses, so gargle::gargle_last_response() can and should be used for post mortem analysis, instead of gm_last_response(). One benefit of this switch is that auth tokens are redacted in the stored response.

Usage

gm_last_response()

Details

[Deprecated]


gmailr documentation built on Jan. 30, 2026, 5:07 p.m.